
// INCLUDES ///////////////////////////////////////////////

#define WIN32_LEAN_AND_MEAN  

// you must #define INITGUID if not done elsewhere
#define INITGUID

#include <windows.h>   // include important windows stuff
#include <windowsx.h> 
#include <mmsystem.h>
#include <objbase.h>
#include <iostream> // include important C/C++ stuff
#include <conio.h>
#include <stdlib.h>
#include <malloc.h>
#include <memory.h>
#include <string.h>
#include <stdarg.h>
#include <stdio.h> 
#include <math.h>
#include <io.h>
#include <fcntl.h>

#include <dinput.h>
#include <ddraw.h>     // directX includes
#include <dsound.h> // include dsound, dmusic
#include <dmksctrl.h>
#include <dmusici.h>
#include <dmusicc.h>
#include <dmusicf.h>

#include "T3DLIB3.H"
#include "T3DLIB1.H"   // include the library header

// DEFINES ////////////////////////////////////////////////

// defines for windows 
#define WINDOW_CLASS_NAME "WINCLASS1"

// default screen size
#define SCREEN_WIDTH    1280  // size of screen
#define SCREEN_HEIGHT   1024
#define SCREEN_BPP      8    // bits per pixel

#define BITMAP_ID            0x4D42 // universal id for a bitmap
#define MAX_COLORS_PALETTE   256

// skelaton directions
#define SKELATON_EAST         0
/*#define SKELATON_NEAST        1  
#define SKELATON_NORTH        2
#define SKELATON_NWEST        3*/
#define SKELATON_WEST         1
/*#define SKELATON_SWEST        5
#define SKELATON_SOUTH        6
#define SKELATON_SEAST        7*/
#define SKELATON_JUMPING_EAST 2
#define SKELATON_JUMPING_WEST 3


#define START_GLOW_COLOR  152 // starting color index to glow
#define END_GLOW_COLOR    159 // ending color index to glow
#define FLOOR_COLOR       116

// PROTOTYPES /////////////////////////////////////////////

// game console
int Game_Init(void *parms=NULL, int num_parms = 0);
int Game_Shutdown(void *parms=NULL, int num_parms = 0);
int Game_Main(void *parms=NULL,  int num_parms = 0);
int Level1_Main(void *parms=NULL, int num_parms=0);
int Level2_Main(void *parms=NULL, int num_parms=0);
int Level3_Main(void *parms=NULL, int num_parms = 0);
int Level4_Main(void *parms=NULL, int num_parms=0);
int Level1_Init();
int Level2_Init();
int Level3_Init();
int Level4_Init();
int Level5_Init();

// GLOBALS ////////////////////////////////////////////////

// windows vars
HWND      main_window_handle = NULL; // globally track main window
int       window_closed      = 0;    // tracks if window is closed
HINSTANCE main_instance      = NULL; // globally track hinstance

int midi_ids[10]; // hold storage for 10 songs ids
int sound_ids[4]; // storage for 4 sound fx ids

LPDIRECTINPUT8        lpdi2      = NULL;    // dinput object
LPDIRECTINPUTDEVICE8  lpdikey2   = NULL;    // dinput keyboard
LPDIRECTINPUTDEVICE8  lpdimouse2 = NULL;    // dinput mouse



DIMOUSESTATE mouse_state2;


int mouse_x,                    // used to track mouse
    mouse_y,
	currentstage,
	pagenum,
	trapnum,
	deaths,
	currentimage,
	platX[12],
	platY[12];

float power;
bool airborne,
	 released,
	 leftdown,
	 rightdown,
	 mousedown,
	 firstrun,
	 platformFlip[4];
bool platformCollision[5];

char buffer[80];                // used to print text

// demo globals
BOB          skelaton,     // the player skelaton
			 pointer,
			 spikeleft,
			 spikeright,
			 spikeup,
			 spikedown,
			 platform,
			 door,
			 wall,
			 trapdoor;

struct Trigger{
	bool timing, shown;
	DWORD timer;
};



BOB traps[5];
Trigger triggered[5];
// animation sequences for bob
int skelaton_anims[4][8] = { {1,2,3,4,5,6,7},
                             {9,10,11,12,13,14,15}, 
							 {16,17,18,19,20,21,22,23},
							 {24,25,26,27,28,29,30,31}};

BITMAP_IMAGE landscape[5];      // the background    landscape 3 pages 3x1
int curr_page = 0;              // current page of landscape

// PROTOTYPES //////////////////////////////////////////////



LRESULT CALLBACK WindowProc(HWND hwnd, 
						    UINT msg, 
                            WPARAM wparam, 
                            LPARAM lparam)
{
// this is the main message handler of the system
PAINTSTRUCT		ps;		// used in WM_PAINT
HDC				hdc;	// handle to a device context
char buffer[80];        // used to print strings

// what is the message 
switch(msg)
	{	
	case WM_CREATE: 
        {
		// do initialization stuff here
        // return success
		return(0);
		} break;
   
	case WM_PAINT: 
		{
		// simply validate the window 
   	    hdc = BeginPaint(hwnd,&ps);	 
        
        // end painting
        EndPaint(hwnd,&ps);

        // return success
		return(0);
   		} break;

	case WM_DESTROY: 
		{

		// kill the application, this sends a WM_QUIT message 
		PostQuitMessage(0);

        // return success
		return(0);
		} break;

	default:break;

    } // end switch

// process any messages that we didn't take care of 
return (DefWindowProc(hwnd, msg, wparam, lparam));

} // end WinProc

// WINMAIN ////////////////////////////////////////////////

int WINAPI WinMain(	HINSTANCE hinstance,
					HINSTANCE hprevinstance,
					LPSTR lpcmdline,
					int ncmdshow)
{

WNDCLASSEX winclass; // this will hold the class we create
HWND	   hwnd;	 // generic window handle
MSG		   msg;		 // generic message
HDC        hdc;      // graphics device context

// first fill in the window class stucture
winclass.cbSize         = sizeof(WNDCLASSEX);
winclass.style			= CS_DBLCLKS | CS_OWNDC | 
                          CS_HREDRAW | CS_VREDRAW;
winclass.lpfnWndProc	= WindowProc;
winclass.cbClsExtra		= 0;
winclass.cbWndExtra		= 0;
winclass.hInstance		= hinstance;
winclass.hIcon			= LoadIcon(NULL, IDI_APPLICATION);
winclass.hCursor		= LoadCursor(NULL, IDC_ARROW); 
winclass.hbrBackground	= (HBRUSH)GetStockObject(BLACK_BRUSH);
winclass.lpszMenuName	= NULL;
winclass.lpszClassName	= WINDOW_CLASS_NAME;
winclass.hIconSm        = LoadIcon(NULL, IDI_APPLICATION);

// save hinstance in global
main_instance = hinstance;

// register the window class
if (!RegisterClassEx(&winclass))
	return(0);

// create the window
if (!(hwnd = CreateWindowEx(NULL,                  // extended style
                            WINDOW_CLASS_NAME,     // class
						    "Escape from Skybase 17", // title
						    WS_POPUP | WS_VISIBLE,
					 	    0,0,	  // initial x,y
						    SCREEN_WIDTH,SCREEN_HEIGHT,  // initial width, height
						    NULL,	  // handle to parent 
						    NULL,	  // handle to menu
						    hinstance,// instance of this application
						    NULL)))	// extra creation parms
return(0);

// save main window handle
main_window_handle = hwnd;

// initialize game here
Game_Init();

// enter main event loop
while(TRUE)
	{
    // test if there is a message in queue, if so get it
	if (PeekMessage(&msg,NULL,0,0,PM_REMOVE))
	   { 
	   // test if this is a quit
       if (msg.message == WM_QUIT)
           break;
	
	   // translate any accelerator keys
	   TranslateMessage(&msg);

	   // send the message to the window proc
	   DispatchMessage(&msg);
	   } // end if
    
       // main game processing goes here
       Game_Main();
       
	} // end while

// closedown game here
Game_Shutdown();

// return to Windows like this
return(msg.wParam);

} // end WinMain

// GAME PROGRAMMING CONSOLE FUNCTIONS ////////////////


int Scaled_Collision_Test(BOB_PTR bob1, BOB_PTR bob2, int w1, int h1, int w2, int h2)						  
{
// are these a valid bobs
if (!bob1 || !bob2)
   return(0);

// get the radi of each rect
int width1  = (w1>>1) - (w1>>3);
int height1 = (h1>>1) - (h1>>3);

int width2  = (w2>>1) - (w2>>3);
int height2 = (h2>>1) - (h2>>3);

// compute center of each rect
int cx1 = bob1->x + width1;
int cy1 = bob1->y + height1;

int cx2 = bob2->x + width2;
int cy2 = bob2->y + height2;

// compute deltas
int dx = abs(cx2 - cx1);
int dy = abs(cy2 - cy1);

// test if rects overlap
if (dx < (width1+width2) && dy < (height1+height2))
   return(1);
else
// else no collision
return(0);

} // end Scaled_Collision_Test

int Game_Init(void *parms,  int num_parms)
{
currentimage=0;
deaths=0;
skelaton.xv=0;
skelaton.yv=0;
currentstage=0;
power=0;
airborne=false;
released=false;
mousedown=false;
leftdown=false;
rightdown=false;



// this function is where you do all the initialization 
// for your game

int index;         // looping var
char filename[80]; // used to build up files names

// initialize directdraw
DDraw_Init(SCREEN_WIDTH, SCREEN_HEIGHT, SCREEN_BPP);

// first create the direct input object
DirectInput8Create(main_instance,DIRECTINPUT_VERSION,IID_IDirectInput8, (void **)&lpdi2,NULL);

// create a mouse device  /////////////////////////////////////
lpdi2->CreateDevice(GUID_SysMouse, &lpdimouse2, NULL);

// set cooperation level
lpdimouse2->SetCooperativeLevel(main_window_handle, DISCL_NONEXCLUSIVE | DISCL_BACKGROUND);

// set data format
lpdimouse2->SetDataFormat(&c_dfDIMouse);

// acquire the mouse
lpdimouse2->Acquire();

DSound_Init();

// initialize directmusic
DMusic_Init();

sound_ids[0] = DSound_Load_WAV("scream.WAV");

midi_ids[0] = DMusic_Load_MIDI("title.mid");
midi_ids[1] = DMusic_Load_MIDI("story.mid");
midi_ids[2] = DMusic_Load_MIDI("game.mid");
midi_ids[3] = DMusic_Load_MIDI("end.mid");
mouse_x = screen_height/2;
mouse_y = screen_height/2;


// load in each page of the scrolling background
for (index = 0; index<5; index++)
    {
    // build up file name
    sprintf(filename,"LANDSCAPE%d.BMP",index);

    // load the background
    Load_Bitmap_File(&bitmap8bit, filename);

    // create and load the reactor bitmap image
    Create_Bitmap(&landscape[index], 0,0, 1280, 1024);
    Load_Image_Bitmap(&landscape[index],&bitmap8bit,0,0,BITMAP_EXTRACT_MODE_ABS);
    Unload_Bitmap_File(&bitmap8bit);

    } // end for index

// set the palette to background image palette
Set_Palette(bitmap8bit.palette);

// now let's load in all the frames for the skelaton!!!

// create skelaton bob
if (!Create_BOB(&skelaton,0,0,72,74,32, // 56x72
           BOB_ATTR_VISIBLE | BOB_ATTR_MULTI_ANIM,DDSCAPS_SYSTEMMEMORY))
   return(0);


Unload_Bitmap_File(&bitmap8bit);

Load_Bitmap_File(&bitmap8bit, "PAINT.BMP");

// create the pointer bob
Create_BOB(&pointer,mouse_x,mouse_y,31,33,1,
           BOB_ATTR_VISIBLE | BOB_ATTR_SINGLE_FRAME,DDSCAPS_SYSTEMMEMORY);    

// load the image for the pointer in
Load_Frame_BOB(&pointer,&bitmap8bit,0,0,0,BITMAP_EXTRACT_MODE_CELL);


Unload_Bitmap_File(&bitmap8bit);




// load the frames in 8 directions, 4 frames each
// each set of frames has a walk and a fire, frame sets
// are loaded in counter clockwise order looking down
// from a birds eys view or the x-z plane
for (int direction = 0; direction < 4; direction++)
    { 
    // build up file name
    sprintf(filename,"QUENSP%d.BMP",direction); // skelsp

    // load in new bitmap file
    Load_Bitmap_File(&bitmap8bit,filename);
	
    Load_Frame_BOB(&skelaton,&bitmap8bit,0+direction*8,0,0,BITMAP_EXTRACT_MODE_CELL);  
    Load_Frame_BOB(&skelaton,&bitmap8bit,1+direction*8,1,0,BITMAP_EXTRACT_MODE_CELL);  
    Load_Frame_BOB(&skelaton,&bitmap8bit,2+direction*8,2,0,BITMAP_EXTRACT_MODE_CELL);  
    Load_Frame_BOB(&skelaton,&bitmap8bit,3+direction*8,3,0,BITMAP_EXTRACT_MODE_CELL);
	Load_Frame_BOB(&skelaton,&bitmap8bit,4+direction*8,0,1,BITMAP_EXTRACT_MODE_CELL);
	Load_Frame_BOB(&skelaton,&bitmap8bit,5+direction*8,1,1,BITMAP_EXTRACT_MODE_CELL);
	Load_Frame_BOB(&skelaton,&bitmap8bit,6+direction*8,2,1,BITMAP_EXTRACT_MODE_CELL);
	Load_Frame_BOB(&skelaton,&bitmap8bit,7+direction*8,3,1,BITMAP_EXTRACT_MODE_CELL);

    // unload the bitmap file
    Unload_Bitmap_File(&bitmap8bit);

    // set the animation sequences for skelaton
	if(direction<3)
		Load_Animation_BOB(&skelaton,direction,7,skelaton_anims[direction]);
	else
		Load_Animation_BOB(&skelaton,direction,8,skelaton_anims[direction]);

    } // end for direction





// set up stating state of skelaton
Set_Animation_BOB(&skelaton, 0);
Set_Anim_Speed_BOB(&skelaton, 3);
Set_Vel_BOB(&skelaton, 0,0);
Set_Pos_BOB(&skelaton, 16, 680); // right above the floor


//Platform,spike,door

if (!Create_BOB(&platform,0,0,100,60,1,
           BOB_ATTR_VISIBLE | BOB_ATTR_MULTI_ANIM ,DDSCAPS_SYSTEMMEMORY))
   return(0);

// load the platform
Load_Bitmap_File(&bitmap8bit,"Platform.BMP");

Load_Frame_BOB(&platform,&bitmap8bit,0,0,0,BITMAP_EXTRACT_MODE_CELL); 
//unload the bitmap file
Unload_Bitmap_File(&bitmap8bit);

// set up stating state of platform
Set_Vel_BOB(&platform, 0,0);
Set_Pos_BOB(&platform, 100, 150); // I EDITED THIS FOR FUTURE REFERENCE. HIGH ABOVE THE FLOOR


Load_Bitmap_File(&bitmap8bit, "trapdoor.BMP");
Create_BOB(&trapdoor,0,0,100,60,1,
           BOB_ATTR_VISIBLE | BOB_ATTR_MULTI_ANIM,DDSCAPS_SYSTEMMEMORY);    
Load_Frame_BOB(&trapdoor,&bitmap8bit,0,0,0,BITMAP_EXTRACT_MODE_CELL);
Unload_Bitmap_File(&bitmap8bit);

Set_Vel_BOB(&trapdoor,0,0);
Set_Pos_BOB(&trapdoor,0,0);

for(int i=0; i<5; i++)
{
	traps[i]=trapdoor;
	triggered[i].shown=true;
}
// I CREATED THIS CODE FOR FUTURE REFERENCE
if(!Create_BOB(&spikeleft,0,0,400,400,1, BOB_ATTR_VISIBLE | BOB_ATTR_MULTI_ANIM, DDSCAPS_SYSTEMMEMORY))
   return (0);
Load_Bitmap_File(&bitmap8bit, "spikeleft.BMP");
Load_Frame_BOB(&spikeleft,&bitmap8bit,0,0,0,BITMAP_EXTRACT_MODE_CELL);
Unload_Bitmap_File(&bitmap8bit);
Set_Vel_BOB(&spikeleft,0,0);
Set_Pos_BOB(&spikeleft,250,420);

if(!Create_BOB(&spikedown,0,0,400,400,1, BOB_ATTR_VISIBLE | BOB_ATTR_MULTI_ANIM, DDSCAPS_SYSTEMMEMORY))
   return (0);
Load_Bitmap_File(&bitmap8bit, "SpikeDown.BMP");
Load_Frame_BOB(&spikedown,&bitmap8bit,0,0,0,BITMAP_EXTRACT_MODE_CELL);
Unload_Bitmap_File(&bitmap8bit);
Set_Vel_BOB(&spikedown,0,0);
Set_Pos_BOB(&spikedown,250,420);

if(!Create_BOB(&spikeright,0,0,400,400,1, BOB_ATTR_VISIBLE | BOB_ATTR_MULTI_ANIM, DDSCAPS_SYSTEMMEMORY))
   return (0);
Load_Bitmap_File(&bitmap8bit, "spikeright.BMP");
Load_Frame_BOB(&spikeright,&bitmap8bit,0,0,0,BITMAP_EXTRACT_MODE_CELL);
Unload_Bitmap_File(&bitmap8bit);
Set_Vel_BOB(&spikeright,0,0);
Set_Pos_BOB(&spikeright,250,420);

if(!Create_BOB(&spikeup,0,0,400,400,1, BOB_ATTR_VISIBLE | BOB_ATTR_MULTI_ANIM, DDSCAPS_SYSTEMMEMORY))
   return (0);
Load_Bitmap_File(&bitmap8bit, "spikeup.BMP");
Load_Frame_BOB(&spikeup,&bitmap8bit,0,0,0,BITMAP_EXTRACT_MODE_CELL);
Unload_Bitmap_File(&bitmap8bit);
Set_Vel_BOB(&spikeup,0,0);
Set_Pos_BOB(&spikeup,250,420);

//Wall
if(!Create_BOB(&wall,0,0,180,180,1,BOB_ATTR_VISIBLE | BOB_ATTR_MULTI_ANIM, DDSCAPS_SYSTEMMEMORY))
	return (0);
Load_Bitmap_File(&bitmap8bit, "Wall.BMP");
Load_Frame_BOB(&wall,&bitmap8bit,0,0,0, BITMAP_EXTRACT_MODE_CELL);
Unload_Bitmap_File(&bitmap8bit);
Set_Vel_BOB(&wall,0,0);
Set_Pos_BOB(&wall,280,240);


//Door
if(!Create_BOB(&door,0,0,80,100,1,BOB_ATTR_VISIBLE | BOB_ATTR_MULTI_ANIM, DDSCAPS_SYSTEMMEMORY))
	return (0);
Load_Bitmap_File(&bitmap8bit, "Door.BMP");
Load_Frame_BOB(&door,&bitmap8bit,0,0,0,BITMAP_EXTRACT_MODE_CELL);
Unload_Bitmap_File(&bitmap8bit);
Set_Vel_BOB(&door,0,0);
Set_Pos_BOB(&door,900,600);

// set clipping rectangle to screen extents so mouse cursor
// doens't mess up at edges
RECT screen_rect = {0,0,screen_width,screen_height};
lpddclipper = DDraw_Attach_Clipper(lpddsback,1,&screen_rect);

// hide the mouse
ShowCursor(FALSE);

//Start music
DMusic_Play(midi_ids[0]);
// return success
return(1);

} // end Game_Init

///////////////////////////////////////////////////////////

int Game_Shutdown(void *parms,  int num_parms)
{
// this function is where you shutdown your game and
// release all resources that you allocated

// kill the landscape
for (int index=0; index<2; index++)
    Destroy_Bitmap(&landscape[index]);

// kill skelaton
Destroy_BOB(&skelaton);
Destroy_BOB(&pointer);
Destroy_BOB(&door);
Destroy_BOB(&wall);
Destroy_BOB(&platform);
Destroy_BOB(&spikeleft);
Destroy_BOB(&spikeright);
Destroy_BOB(&spikeup);
Destroy_BOB(&spikedown);
Destroy_BOB(&trapdoor);

DSound_Stop_All_Sounds();

// delete all sounds
DSound_Delete_All_Sounds();

// shutdown directsound
DSound_Shutdown();

// delete all the music
DMusic_Delete_All_MIDI();

// shutdown directmusic
DMusic_Shutdown();
// shutdonw directdraw
DDraw_Shutdown();

// return success
return(1);
} // end Game_Shutdown

///////////////////////////////////////////////////////////
int Menu_Main(void *parms, int num_parms)
{
	static bool reset=true;

	if (KEY_DOWN(VK_ESCAPE))
		PostMessage(main_window_handle, WM_DESTROY,0,0);

	// start the timing clock
	Start_Clock();
	
	lpdimouse2->GetDeviceState(sizeof(DIMOUSESTATE), (LPVOID)&mouse_state2);

	//Adjust mouse pointer sprite on screen to match mouse movement
	mouse_x+=(mouse_state2.lX);
	mouse_y+=(mouse_state2.lY);

	

	//Move mouse back onto screen
	if (mouse_x >= screen_width)
	   mouse_x = screen_width-1;
	else
	if (mouse_x < 0)
	   mouse_x = 0;

	// now the y boundaries
	if (mouse_y >= screen_height)
	   mouse_y= screen_height-1;
	else
	if (mouse_y < 0)
	   mouse_y = 0;

	//Set cursor object to mouse position
	pointer.x = mouse_x - 16;
	pointer.y = mouse_y - 16;
	
	//Check for button click

	if (KEY_DOWN(VK_RETURN))
	{
		if(currentimage==0)
			DMusic_Play(midi_ids[1]);
		if(reset)
		{
			currentimage++;
			reset=false;
		}
	}
	else
		reset=true;
	if(currentimage==3)
	{
		firstrun=true;
		currentstage++;
	    platformFlip[0]=false;
		Level1_Init();
		return(1);
	}
	// clear the drawing surface
		

	DDraw_Fill_Surface(lpddsback, 0);

	// lock the back buffer
	DDraw_Lock_Back_Surface();

	// draw the background reactor image
	Draw_Bitmap(&landscape[currentimage], back_buffer, back_lpitch, 0);

	// unlock the back buffer
	DDraw_Unlock_Back_Surface();

	Draw_BOB(&pointer,lpddsback);

	// flip the surfaces
	DDraw_Flip();

	// sync to 30 fps
	Wait_Clock(30);

	return(1);
}

int Level1_Init()
{
	DMusic_Play(midi_ids[2]);
	platform.x=100;
	platform.y=150;
	Set_Pos_BOB(&spikeleft,570,SCREEN_HEIGHT - 120);
	Set_Pos_BOB(&spikeright,900,SCREEN_HEIGHT - 120);
	Set_Pos_BOB(&spikeup,600,SCREEN_HEIGHT - 720);
	Set_Pos_BOB(&wall,600,SCREEN_HEIGHT - 690);
	Set_Pos_BOB(&door,SCREEN_WIDTH - door.width,SCREEN_HEIGHT - door.height - 100);
	int tempplatY[11] = {SCREEN_HEIGHT - 180,SCREEN_HEIGHT - 300,SCREEN_HEIGHT - 450,
				SCREEN_HEIGHT - 600,SCREEN_HEIGHT - 700,
				SCREEN_HEIGHT - 600,SCREEN_HEIGHT - 700,
				SCREEN_HEIGHT - 700,SCREEN_HEIGHT - 600,
				SCREEN_HEIGHT - 450, SCREEN_HEIGHT - 300};
	int tempplatX[11] = {400,200,0,200,0,400,600,800,1000,1180,1000};
	for(int i=0;i<11;i++)
	{platY[i]=tempplatY[i]-240;platX[i]=tempplatX[i];}
	pagenum=0;
	return(1);
}

int Level1_Main(void *parms, int num_parms)
{
//Scott Keling
//loop music (3 is stopped)
if(DMusic_Status_MIDI(midi_ids[2])==3)
	DMusic_Play(midi_ids[2]);
//Apply gravity
skelaton.yv+=1;
//Adjust mouse pointer sprite on screen to match mouse movement
mouse_x+=(mouse_state2.lX);
mouse_y+=(mouse_state2.lY);

bool platformCollision=false;
BOB bobptr;


for(int i=0; i<11;i++)
{
	platform.x=platX[i];
	platform.y=platY[i];
	if(platform.x > platform.x-(platform.width-skelaton.width)/2 && platform.x< platform.x+(platform.width+skelaton.width)/2)
	{
		if(Collision_BOBS(&skelaton,&platform))
		{ 
			if(platform.y-50>skelaton.y) 
			{ 
				platformCollision = 1; 
				skelaton.y = skelaton.y-abs(skelaton.yv); 
				skelaton.yv=0; 
				skelaton.xv=0; 
				airborne=false; 
			} 
			else 
			{ 
				skelaton.x-=skelaton.xv; 
				skelaton.y-=skelaton.yv; 
				skelaton.xv=0; 
				skelaton.yv=0; 
				platformCollision=1; 
			} 
		}
	}
}
//Used to tell if the arrow keys were released
if((leftdown && KEY_UP(VK_LEFT)) || (rightdown && KEY_UP(VK_RIGHT)))
	released=true;

if(KEY_DOWN(VK_LSHIFT) && KEY_DOWN(0x04A))
	{skelaton.x=mouse_x; skelaton.y=mouse_y;}

//Move mouse back onto screen
if (mouse_x >= screen_width)
   mouse_x = screen_width-1;
else
if (mouse_x < 0)
   mouse_x = 0;

// now the y boundaries
if (mouse_y >= screen_height)
   mouse_y= screen_height-1;
else
if (mouse_y < 0)
   mouse_y = 0;


//Set cursor object to mouse position
pointer.x = mouse_x - 16;
pointer.y = mouse_y - 16;

//ENDSK

int          index;             // looping var
int          dx,dy;             // general deltas used in collision detection
lpdimouse2->GetDeviceState(sizeof(DIMOUSESTATE), (LPVOID)&mouse_state2);


static int   player_moving = 0; // tracks player motion
static PALETTEENTRY glow = {0,0,0,PC_NOCOLLAPSE};  // used to animation green border

// check of user is trying to exit
if (KEY_DOWN(VK_ESCAPE))
    PostMessage(main_window_handle, WM_DESTROY,0,0);

// start the timing clock
Start_Clock();

// clear the drawing surface
DDraw_Fill_Surface(lpddsback, 0);

// lock the back buffer
DDraw_Lock_Back_Surface();

// draw the background reactor image
Draw_Bitmap(&landscape[3], back_buffer, back_lpitch, 0);

// unlock the back buffer
DDraw_Unlock_Back_Surface();

// reset motion flag
player_moving = 0;





//Scott Keling
//If mouse button was released
if(mousedown && !mouse_state2.rgbButtons[0])
{
	//If on ground, jump
	if(!airborne)
	{
		//Used for motion calculation
		float xchange=0;
		float ychange=0;
		float totalchange=0;
		airborne=true;
		//Get difference in character to mouse position
		xchange=skelaton.x+33-mouse_x;
		ychange=skelaton.y+36-mouse_y-20;
		//Take the total change to get the ratio of rise vs run
		totalchange=abs(xchange)+abs(ychange);
		
		power+=15;
		//Get direction and jump
		int direction;
		if(xchange>0)
			skelaton.xv=-(int)power*abs(xchange/totalchange);
		else
			skelaton.xv=(int)power*abs(xchange/totalchange);
		if(ychange>0)
			skelaton.yv=-(int)power*abs(ychange/totalchange);
		else
			skelaton.yv=(int)power*abs(ychange/totalchange);
	}
	mousedown=false;
	power=0;
}

if(airborne)
{
	int direction;
	if(skelaton.xv>0)
		direction=SKELATON_JUMPING_EAST;
	else
		direction=SKELATON_JUMPING_WEST;
		
	if(skelaton.curr_animation!=SKELATON_JUMPING_EAST 
		&& skelaton.curr_animation!=SKELATON_JUMPING_WEST)
	{Set_Anim_Speed_BOB(&skelaton, 1);
	Set_Animation_BOB(&skelaton,direction);}
}
else if(skelaton.curr_animation!=SKELATON_EAST 
		&& skelaton.curr_animation!=SKELATON_WEST)
{
	Set_Anim_Speed_BOB(&skelaton, 3);
	Set_Animation_BOB(&skelaton,SKELATON_EAST);
}

//If mouse button is down, increment power up to 30
if (mouse_state2.rgbButtons[0])
{
	mousedown=true;
	if(power<25)
		power+=0.50;
}
//ENDSK

// test direction of motion
if (KEY_DOWN(VK_RIGHT) && !airborne) 
   {
	rightdown=true;
   // move skelaton
   skelaton.xv+=4;
   dx=skelaton.xv+4; dy=0;

   // set motion flag
   player_moving = 1;

   // check animation needs to change
   if (skelaton.curr_animation != SKELATON_EAST)
      Set_Animation_BOB(&skelaton,SKELATON_EAST);

   } // end if
else
if (KEY_DOWN(VK_LEFT) && !airborne)  
   {
	leftdown=true;
   // move skelaton
   skelaton.xv-=4;
   dx=skelaton.xv-4; dy=0; 
   
   // set motion flag
   player_moving = 1;

   // check animation needs to change
   if (skelaton.curr_animation != SKELATON_WEST)
      Set_Animation_BOB(&skelaton,SKELATON_WEST);

   } // end if

//Scott Keling
//If left or right key has been released
//Stop character if he is on ground (this keeps him moving in the air)
if(released && !airborne)
{
	skelaton.xv=0;
	leftdown=false;
	rightdown=false;
	released=false;
}


// apply downward gravity to player,
// so player follows terrain
skelaton.y+=skelaton.yv+1;

//apply x velocity
skelaton.x+=skelaton.xv;

// only animate if player is moving
if (player_moving || airborne)
   {
   // animate skelaton
   Animate_BOB(&skelaton);
   } // end if
else
{
	if(skelaton.curr_animation == SKELATON_EAST
	|| skelaton.curr_animation == SKELATON_JUMPING_EAST)
		skelaton.curr_frame=0;
	else
		skelaton.curr_frame=8;
}


if(door.x > door.x-(door.width-skelaton.width)/2 && door.x< door.x+(door.width+skelaton.width)/2)
	if(Collision_BOBS(&skelaton,&door) == 1)
		{
			// player has reached the end of the lvl. 
			currentstage++;
			skelaton.x = 100;
			skelaton.y = 900;
			skelaton.xv=0;
			skelaton.yv=0;
			Level2_Init();
			return(1);
		}


for(int i = 0; i < 11; i++)
{
	Set_Pos_BOB(&platform,platX[i],platY[i]);
	Draw_BOB(&platform,lpddsback);
}


// lock surface, so we can scan it
DDraw_Lock_Back_Surface();
   

//Set for if player jumps off platform, 
//next while statement will reset it if player is on ground
airborne=true;
// call the color scanner with FLOOR_COLOR, the color of the glowing floor
// try to center the scan on the feet of the player, make sure feet stay
// in contact with floor
while(Color_Scan(skelaton.x+16, skelaton.y+24,
               skelaton.x+skelaton.width-32, skelaton.y+skelaton.height-12,                                    
               FLOOR_COLOR, FLOOR_COLOR, back_buffer,back_lpitch))
   {
   // push the skelaton upward, to keep it on the floor
	    skelaton.yv=0;
		skelaton.xv=0;
		airborne=false;
		leftdown=false;
		rightdown=false;
		released=false;
		skelaton.y-=skelaton.yv+1;
		
   } // end while
   
// done, so unlock
DDraw_Unlock_Back_Surface();

// draw the skelaton
Draw_BOB(&skelaton, lpddsback);

Draw_BOB(&door,lpddsback);
//draw the spike

for(int i=0; i<20; i++)
{
	bobptr=spikeleft;
	bobptr.y-=(i*30);
	if(bobptr.x > bobptr.x-(bobptr.width-skelaton.width)/2 && bobptr.x< bobptr.x+(bobptr.width+skelaton.width)/2)
		if(Scaled_Collision_Test(&skelaton,&bobptr, skelaton.width, skelaton.height, 30,30))
			{skelaton.x=100; skelaton.y=900;skelaton.xv=0;skelaton.yv=0;DSound_Play(sound_ids[0],0);deaths++;} 
	Draw_Scaled_BOB(&bobptr,30,30,lpddsback);
}
for(int i=0; i<20; i++)
{
	bobptr=spikeright;
	bobptr.y-=(i*30);
	if(bobptr.x > bobptr.x-(bobptr.width-skelaton.width)/2 && bobptr.x< bobptr.x+(bobptr.width+skelaton.width)/2)
		if(Scaled_Collision_Test(&skelaton,&bobptr, skelaton.width, skelaton.height, 30,30))
			{skelaton.x=100; skelaton.y=900;skelaton.xv=0;skelaton.yv=0;DSound_Play(sound_ids[0],0);deaths++;} 
	Draw_Scaled_BOB(&bobptr,30,30,lpddsback);
}
for(int i=0; i<10; i++)
{
	bobptr=spikeup;
	bobptr.x+=(i*30);
	if(bobptr.x > bobptr.x-(bobptr.width-skelaton.width)/2 && bobptr.x< bobptr.x+(bobptr.width+skelaton.width)/2)
		if(Scaled_Collision_Test(&skelaton,&bobptr, skelaton.width, skelaton.height, 30,30))
			{skelaton.x=100; skelaton.y=900;skelaton.xv=0;skelaton.yv=0;DSound_Play(sound_ids[0],0);deaths++;} 
	Draw_Scaled_BOB(&bobptr,30,30,lpddsback);
}
	

//Draw_Scaled_BOB(&spike, 30, 30, lpddsback);

//Draw the wall




Draw_Scaled_BOB(&wall,300,600,lpddsback);
if(wall.x > wall.x-(wall.width-skelaton.width)/2 
&& wall.x< wall.x+(wall.width+skelaton.width)/2)
{
		if(Scaled_Collision_Test(&skelaton,&wall, skelaton.width, skelaton.height, 300,600))
		{
				if(wall.y-50>skelaton.y)
				{
					skelaton.y = skelaton.y-abs(skelaton.yv);
					skelaton.yv=0;
					skelaton.xv=0;
					airborne=false;
				}
				else
				{
					skelaton.x=0;
					skelaton.xv*=-0.3;
					skelaton.yv*=0.3;
				}
			}
}

//draw the platform
//Draw_BOB(&platform, lpddsback);



//Scott Keling
// draw some text
//sprintf(buffer, "Mouse_x=%d, Mouse_y=%d, skelaton.xv=%f, skelaton.yv=%f", mouse_x, mouse_y, skelaton.xv, skelaton.yv);
sprintf(buffer, "power=%d", (int)(power*4));

//Color power meter
if(power<8)
	Draw_Text_GDI(buffer,8,8,RGB(255,255,255),lpddsback);
else if(power<16)
	Draw_Text_GDI(buffer,8,8,RGB(255,255,0),lpddsback);
else if(power<25)
	Draw_Text_GDI(buffer,8,8,RGB(205,140,0),lpddsback);
else
	Draw_Text_GDI(buffer,8,8,RGB(255,0,0),lpddsback);
//ENDSK

sprintf(buffer, "Deaths=%d", deaths);
Draw_Text_GDI(buffer, 1100, 8, RGB(255,255,255),lpddsback);

// test for page flip right
	if (skelaton.x > SCREEN_WIDTH - (skelaton.width >> 1))
	{
		skelaton.x-=10;
		skelaton.xv*=-0.3;
		skelaton.yv*=0.3;
	}

else // page flip right?*/
	if (skelaton.x < -(skelaton.width >> 1))
	{
		skelaton.x=-(skelaton.width >> 1);
		skelaton.xv*=-0.3;
		skelaton.yv*=0.3;
	}


//Scott Keling -draw mouse pointer
Draw_BOB(&pointer,lpddsback);

// flip the surfaces
DDraw_Flip();

Destroy_BOB(&bobptr);
// sync to 30 fps
Wait_Clock(30);

firstrun=false;
// return success
return(1);

} // end Game_Main

int Level2_Init()
{
	platform.x=100;
	platform.y=150;
	trapnum=3;
	traps[0].x=100;
	traps[0].y=600;
	traps[1].x=600;
	traps[1].y=600;
	traps[2].x=900;
	traps[2].y=600;
	wall.x=280;
	wall.y=220;
	door.x=1100;
	door.y=200;
	spikeleft.x=250;
	spikeleft.y=220;
	spikeup.x=280;
	spikeup.y=190;
	spikedown.x=730;
	spikedown.y=430;
	return(1);
	
}
int Level2_Main(void *parms, int num_parms)
{
//Scott Keling
//loop music (3 is stopped)
if(DMusic_Status_MIDI(midi_ids[2])==3)
	DMusic_Play(midi_ids[2]);
//Apply gravity
skelaton.yv+=1;
//Adjust mouse pointer sprite on screen to match mouse movement
mouse_x+=(mouse_state2.lX);
mouse_y+=(mouse_state2.lY);

bool platformCollision=false;
BOB bobptr;

if(door.x > door.x-(door.width-skelaton.width)/2 && door.x< door.x+(door.width+skelaton.width)/2)
	if(Collision_BOBS(&skelaton,&door) == 1)
		{
			// player has reached the end of the lvl. 
			currentstage++;
			skelaton.x = 50;
			skelaton.y = 40;
			skelaton.xv=0;
			skelaton.yv=0;
			Level3_Init();
			return(1);
		}

if(platform.x > platform.x-(platform.width-skelaton.width)/2 && platform.x< platform.x+(platform.width+skelaton.width)/2)
	if(Collision_BOBS(&skelaton,&platform) == 1)
		{
			if(platform.y-50>skelaton.y)
			{
				platformCollision = 1;
				skelaton.y = skelaton.y-abs(skelaton.yv);
				skelaton.yv=0;
				skelaton.xv=0;
				airborne=false;
			}
			else
			{
				skelaton.x-=skelaton.xv;
				skelaton.y-=skelaton.yv;
				skelaton.xv=0;
				skelaton.yv=0;
				platformCollision=1;
			}
		}

	
bobptr=platform;
bobptr.x=1030;
bobptr.y=260;
if(bobptr.x > bobptr.x-(bobptr.width-skelaton.width)/2 && bobptr.x< bobptr.x+(bobptr.width+skelaton.width)/2)
	if(Collision_BOBS(&skelaton,&bobptr) == 1)
		{
			if(bobptr.y-50>skelaton.y)
			{
				skelaton.y = skelaton.y-abs(skelaton.yv);
				skelaton.yv=0;
				skelaton.xv=0;
				airborne=false;
			}
			else
			{
				skelaton.x-=skelaton.xv;
				skelaton.y-=skelaton.yv;
				skelaton.xv=0;
				skelaton.yv=0;
			}
		}

bobptr.x+=100;
if(bobptr.x > bobptr.x-(bobptr.width-skelaton.width)/2 && bobptr.x< bobptr.x+(bobptr.width+skelaton.width)/2)
	if(Collision_BOBS(&skelaton,&bobptr) == 1)
		{
			if(bobptr.y-50>skelaton.y)
			{
				skelaton.y = skelaton.y-abs(skelaton.yv);
				skelaton.yv=0;
				skelaton.xv=0;
				airborne=false;
			}
			else
			{
				skelaton.x-=skelaton.xv;
				skelaton.y-=skelaton.yv;
				skelaton.xv=0;
				skelaton.yv=0;
			}
		}


for(int i=0; i<trapnum; i++)
{
	if(triggered[i].shown
		&& traps[i].x > traps[i].x-(traps[i].width-skelaton.width)/2 
		&& traps[i].x< traps[i].x+(traps[i].width+skelaton.width)/2)
		if(Collision_BOBS(&skelaton,&traps[i]) == 1)
			{
				if(traps[i].y-50>skelaton.y)
				{
					skelaton.y = skelaton.y-abs(skelaton.yv);
					skelaton.yv=0;
					skelaton.xv=0;
					airborne=false;
					if(!triggered[i].timing)
					{
						triggered[i].timing=true;
						triggered[i].timer=GetTickCount();
					}
				}
				else
				{
					skelaton.x-=skelaton.xv;
					skelaton.y-=skelaton.yv;
					skelaton.xv*=0.3;
					skelaton.yv=0;
				}
			}
}

if(!platformFlip[0])
{
		if(platform.x > 500)
			platformFlip[0] = true;

	   // move platform
	   platform.x+=2;
	  // dx=2; dy=0;
	   if(platformCollision)
		   skelaton.x+=2;
}
else
{
		if(platform.x < 100)
			platformFlip[0] = false;

		// move platform
		platform.x+=-2;
		//dx=-2; dy=0;
		if(platformCollision)
			skelaton.x-=2;
}
//Used to tell if the arrow keys were released
if((leftdown && KEY_UP(VK_LEFT)) || (rightdown && KEY_UP(VK_RIGHT)))
	released=true;

if(KEY_DOWN(VK_LSHIFT) && KEY_DOWN(0x04A))
	{skelaton.x=mouse_x; skelaton.y=mouse_y;}

//Move mouse back onto screen
if (mouse_x >= screen_width)
   mouse_x = screen_width-1;
else
if (mouse_x < 0)
   mouse_x = 0;

// now the y boundaries
if (mouse_y >= screen_height)
   mouse_y= screen_height-1;
else
if (mouse_y < 0)
   mouse_y = 0;


//Set cursor object to mouse position
pointer.x = mouse_x - 16;
pointer.y = mouse_y - 16;

//ENDSK

int          index;             // looping var
int          dx,dy;             // general deltas used in collision detection
lpdimouse2->GetDeviceState(sizeof(DIMOUSESTATE), (LPVOID)&mouse_state2);


static int   player_moving = 0; // tracks player motion
static PALETTEENTRY glow = {0,0,0,PC_NOCOLLAPSE};  // used to animation green border

// check of user is trying to exit
if (KEY_DOWN(VK_ESCAPE))
    PostMessage(main_window_handle, WM_DESTROY,0,0);

// start the timing clock
Start_Clock();

// clear the drawing surface
DDraw_Fill_Surface(lpddsback, 0);

// lock the back buffer
DDraw_Lock_Back_Surface();

// draw the background reactor image
Draw_Bitmap(&landscape[3], back_buffer, back_lpitch, 0);

// unlock the back buffer
DDraw_Unlock_Back_Surface();

// reset motion flag
player_moving = 0;



//Scott Keling
//If mouse button was released
if(mousedown && !mouse_state2.rgbButtons[0])
{
	//If on ground, jump
	if(!airborne)
	{
		//Used for motion calculation
		float xchange=0;
		float ychange=0;
		float totalchange=0;
		airborne=true;
		//Get difference in character to mouse position
		xchange=skelaton.x+33-mouse_x;
		ychange=skelaton.y+36-mouse_y-20;
		//Take the total change to get the ratio of rise vs run
		totalchange=abs(xchange)+abs(ychange);
		
		power+=15;
		//Get direction and jump
		int direction;
		if(xchange>0)
			skelaton.xv=-(int)power*abs(xchange/totalchange);
		else
			skelaton.xv=(int)power*abs(xchange/totalchange);
		if(ychange>0)
			skelaton.yv=-(int)power*abs(ychange/totalchange);
		else
			skelaton.yv=(int)power*abs(ychange/totalchange);
	}
	mousedown=false;
	power=0;
}

if(airborne)
{
	int direction;
	if(skelaton.xv>0)
		direction=SKELATON_JUMPING_EAST;
	else
		direction=SKELATON_JUMPING_WEST;
		
	if(skelaton.curr_animation!=SKELATON_JUMPING_EAST 
		&& skelaton.curr_animation!=SKELATON_JUMPING_WEST)
	{Set_Anim_Speed_BOB(&skelaton, 1);
	Set_Animation_BOB(&skelaton,direction);}
}
else if(skelaton.curr_animation!=SKELATON_EAST 
		&& skelaton.curr_animation!=SKELATON_WEST)
{
	Set_Anim_Speed_BOB(&skelaton, 3);
	Set_Animation_BOB(&skelaton,SKELATON_EAST);
}

//If mouse button is down, increment power up to 30
if (mouse_state2.rgbButtons[0])
{
	mousedown=true;
	if(power<25)
		power+=0.50;
}
//ENDSK

// test direction of motion
if (KEY_DOWN(VK_RIGHT) && !airborne) 
   {
	rightdown=true;
   // move skelaton
   skelaton.xv+=4;
   dx=skelaton.xv+4; dy=0;

   // set motion flag
   player_moving = 1;

   // check animation needs to change
   if (skelaton.curr_animation != SKELATON_EAST)
      Set_Animation_BOB(&skelaton,SKELATON_EAST);

   } // end if
else
if (KEY_DOWN(VK_LEFT) && !airborne)  
   {
	leftdown=true;
   // move skelaton
   skelaton.xv-=4;
   dx=skelaton.xv-4; dy=0; 
   
   // set motion flag
   player_moving = 1;

   // check animation needs to change
   if (skelaton.curr_animation != SKELATON_WEST)
      Set_Animation_BOB(&skelaton,SKELATON_WEST);

   } // end if

//Scott Keling
//If left or right key has been released
//Stop character if he is on ground (this keeps him moving in the air)
if(released && !airborne)
{
	skelaton.xv=0;
	leftdown=false;
	rightdown=false;
	released=false;
}


// apply downward gravity to player,
// so player follows terrain
skelaton.y+=skelaton.yv+1;

//apply x velocity
skelaton.x+=skelaton.xv;

// only animate if player is moving
if (player_moving || airborne)
   {
   // animate skelaton
   Animate_BOB(&skelaton);
   } // end if
else
{
	if(skelaton.curr_animation == SKELATON_EAST
	|| skelaton.curr_animation == SKELATON_JUMPING_EAST)
		skelaton.curr_frame=0;
	else
		skelaton.curr_frame=8;
}
// lock surface, so we can scan it
DDraw_Lock_Back_Surface();
   

//Set for if player jumps off platform, 
//next while statement will reset it if player is on ground
airborne=true;
// call the color scanner with FLOOR_COLOR, the color of the glowing floor
// try to center the scan on the feet of the player, make sure feet stay
// in contact with floor
while(Color_Scan(skelaton.x+16, skelaton.y+24,
               skelaton.x+skelaton.width-32, skelaton.y+skelaton.height-12,                                    
               FLOOR_COLOR, FLOOR_COLOR, back_buffer,back_lpitch))
   {
   // push the skelaton upward, to keep it on the floor
	    skelaton.yv=0;
		skelaton.xv=0;
		airborne=false;
		leftdown=false;
		rightdown=false;
		released=false;
		skelaton.y-=skelaton.yv+1;
		
   } // end while
   
// done, so unlock
DDraw_Unlock_Back_Surface();


Draw_BOB(&door,lpddsback);
//draw the spike

//Draw_BOB(&spike,lpddsback);
for(int i=0;i<12;i++)
{
	bobptr=spikeleft;
	bobptr.y+=(i*30);
	if(bobptr.y > bobptr.y-(bobptr.height-skelaton.height)/2 && bobptr.y< bobptr.y+(bobptr.height+skelaton.height)/2)
		if(Scaled_Collision_Test(&skelaton,&bobptr, skelaton.width, skelaton.height, 30,30))
			{skelaton.x=100; skelaton.y=900;skelaton.xv=0;skelaton.yv=0;DSound_Play(sound_ids[0],0);deaths++;} 
	Draw_Scaled_BOB(&bobptr,30,30,lpddsback);
	
}

for(int i=0; i<12; i++)
{
	bobptr=spikeleft;
	bobptr.y+=((i-5)*30);
	bobptr.x=700;
	if(bobptr.y > bobptr.y-(bobptr.height-skelaton.height)/2 && bobptr.y< bobptr.y+(bobptr.height+skelaton.height)/2)
		if(Scaled_Collision_Test(&skelaton,&bobptr, skelaton.width, skelaton.height, 30,30))
			{skelaton.x=100; skelaton.y=900;skelaton.xv=0;skelaton.yv=0;DSound_Play(sound_ids[0],0);deaths++;} 
	Draw_Scaled_BOB(&bobptr,30,30,lpddsback);
}

for(int i=0; i<6; i++)
{
	bobptr=spikeup;
	bobptr.x+=(i*30);
	if(bobptr.x > bobptr.x-(bobptr.width-skelaton.width)/2 && bobptr.x< bobptr.x+(bobptr.width+skelaton.width)/2)
		if(Scaled_Collision_Test(&skelaton,&bobptr, skelaton.width, skelaton.height, 30,30))
			{skelaton.x=100; skelaton.y=900;skelaton.xv=0;skelaton.yv=0;DSound_Play(sound_ids[0],0);deaths++;} 
	Draw_Scaled_BOB(&bobptr,30,30,lpddsback);
}

for(int i=0; i<20; i++)
{
	bobptr=spikeup;
	bobptr.y=896;
	bobptr.x+=180+(i*30);
	if(bobptr.x > bobptr.x-(bobptr.width-skelaton.width)/2 && bobptr.x< bobptr.x+(bobptr.width+skelaton.width)/2)
		if(Scaled_Collision_Test(&skelaton,&bobptr, skelaton.width, skelaton.height, 30,30))
			{skelaton.x=100; skelaton.y=900;skelaton.xv=0;skelaton.yv=0;DSound_Play(sound_ids[0],0);deaths++;} 
	Draw_Scaled_BOB(&bobptr,30,30,lpddsback);
}
for(int i=0; i<6; i++)
{
	bobptr=spikedown;
	bobptr.x+=(i*30);
	if(bobptr.x > bobptr.x-(bobptr.width-skelaton.width)/2 && bobptr.x< bobptr.x+(bobptr.width+skelaton.width)/2)
		if(Scaled_Collision_Test(&skelaton,&bobptr, skelaton.width, skelaton.height, 30,30))
			{skelaton.x=100; skelaton.y=900;skelaton.xv=0;skelaton.yv=0;DSound_Play(sound_ids[0],0);deaths++;} 
	Draw_Scaled_BOB(&bobptr,30,30,lpddsback);
}
	

for(int i=0;i<trapnum;i++)
{
	if(triggered[i].timing)
	{
		DWORD currtime=GetTickCount();
		if(currtime-triggered[i].timer < 2000)
			Draw_BOB(&traps[i],lpddsback);
		else if(currtime-triggered[i].timer < 7000)
			triggered[i].shown=false;
		else if(currtime-triggered[i].timer > 7000)
		{
			triggered[i].timer=0;
			triggered[i].timing=false;
			triggered[i].shown=true;
		}
	}
	else
		Draw_BOB(&traps[i],lpddsback);
}

//Draw_Scaled_BOB(&spike, 30, 30, lpddsback);

//Draw the wall

for(int i=0; i<4; i++)
{
	bobptr=wall;
	bobptr.y+=(i*180);
	if(bobptr.x > bobptr.x-(bobptr.width-skelaton.width)/2 && bobptr.x< bobptr.x+(bobptr.width+skelaton.width)/2)
		if(Collision_BOBS(&skelaton,&bobptr))
			{
				if(airborne)
				{
				skelaton.x-=skelaton.xv;
				skelaton.y-=skelaton.yv;
				skelaton.xv=0;
				skelaton.yv=0;
				}
				else if(skelaton.curr_animation==SKELATON_EAST)
					skelaton.xv-=5;
				else
					skelaton.xv+=5;
			} 
	Draw_BOB(&bobptr,lpddsback);
}

for(int i=0; i<4; i++)
{
	bobptr=wall;
	bobptr.x=730;
	bobptr.y-=(i*180)-30;
	if(bobptr.x > bobptr.x-(bobptr.width-skelaton.width)/2 
		&& bobptr.x< bobptr.x+(bobptr.width+skelaton.width)/2)
		if(Collision_BOBS(&skelaton,&bobptr))
			{
				if(airborne)
				{
					skelaton.x-=skelaton.xv;
					skelaton.y-=skelaton.yv;
					skelaton.xv=0;
					skelaton.yv=0;
				}
				else if(skelaton.curr_animation==SKELATON_EAST)
					skelaton.xv-=5;
				else
					skelaton.xv+=5;
		}
		Draw_BOB(&bobptr,lpddsback);
}


for(int i=0; i<4; i++)
{
	bobptr=wall;
	bobptr.x=1030;
	bobptr.y+=(i*180)+75;
	if(bobptr.x > bobptr.x-(bobptr.width-skelaton.width)/2
		&& bobptr.x< bobptr.x+(bobptr.width+skelaton.width)/2)
		if(Collision_BOBS(&skelaton,&bobptr))
			{
				if(airborne)
				{
					skelaton.x-=skelaton.xv;
					skelaton.y-=skelaton.yv;
					skelaton.xv=0;
					skelaton.yv=0;
				}
				else if(skelaton.curr_animation==SKELATON_EAST)
					skelaton.xv-=5;
				else
					skelaton.xv+=5;
			}
	Draw_BOB(&bobptr,lpddsback);
	bobptr.x+=180;
	Draw_BOB(&bobptr,lpddsback);
}



//draw the platform
Draw_BOB(&platform, lpddsback);
bobptr=platform;
bobptr.x=1030;
bobptr.y=260;
Draw_BOB(&bobptr,lpddsback);
bobptr.x+=100;
Draw_BOB(&bobptr,lpddsback);


// draw the skelaton

//Scott Keling
// draw some text
//sprintf(buffer, "Mouse_x=%d, Mouse_y=%d, skelaton.xv=%f, skelaton.yv=%f", mouse_x, mouse_y, skelaton.xv, skelaton.yv);
sprintf(buffer, "power=%d", (int)(power*4));

//Color power meter
if(power<8)
	Draw_Text_GDI(buffer,8,8,RGB(255,255,255),lpddsback);
else if(power<16)
	Draw_Text_GDI(buffer,8,8,RGB(255,255,0),lpddsback);
else if(power<25)
	Draw_Text_GDI(buffer,8,8,RGB(205,140,0),lpddsback);
else
	Draw_Text_GDI(buffer,8,8,RGB(255,0,0),lpddsback);
//ENDSK
sprintf(buffer, "Deaths=%d", deaths);
Draw_Text_GDI(buffer, 1100, 8, RGB(255,255,255),lpddsback);

// test for page flip right
	if (skelaton.x > SCREEN_WIDTH - (skelaton.width >> 1))
	{
		skelaton.x-=10;
		skelaton.xv*=-0.3;
		skelaton.yv*=0.3;
	}

else // page flip right?*/
	if (skelaton.x < -(skelaton.width >> 1))
	{
		skelaton.x=-(skelaton.width >> 1);
		skelaton.xv*=-0.3;
		skelaton.yv*=0.3;
	}

Draw_BOB(&skelaton, lpddsback);

//Scott Keling -draw mouse pointer
Draw_BOB(&pointer,lpddsback);

// flip the surfaces
DDraw_Flip();

Destroy_BOB(&bobptr);
// sync to 30 fps
Wait_Clock(30);

firstrun=false;
// return success
return(1);

} // end Game_Main


int Level3_Init()
{
	platform.x=700;
	platform.y=150;
	trapnum=5;
	traps[0].x=40;
	traps[0].y=800;
	traps[1].x=170;
	traps[1].y=400;
	traps[2].x=400;
	traps[2].y=700;
	traps[3].x=700;
	traps[3].y=800;
	traps[4].x=550;
	traps[4].y=350;
	wall.x=280;
	wall.y=400;
	door.x=1160;
	door.y=830;
	spikeleft.x=250;
	spikeleft.y=0;
	spikeup.x=0;
	spikeup.y=900;
	spikedown.x=280;
	spikedown.y=580;
	spikeright.x=0;
	spikeright.y=170;
	for(int i=0; i<trapnum; i++)
		triggered[i].shown=true;
	return(1);
}

int Level3_Main(void *parms, int num_parms)
{
//Scott Keling
//loop music (3 is stopped)
if(DMusic_Status_MIDI(midi_ids[2])==3)
	DMusic_Play(midi_ids[2]);
//Apply gravity
skelaton.yv+=1;
//Adjust mouse pointer sprite on screen to match mouse movement
mouse_x+=(mouse_state2.lX);
mouse_y+=(mouse_state2.lY);

bool platformCollision=false;
BOB bobptr;

if(door.x > door.x-(door.width-skelaton.width)/2 && door.x< door.x+(door.width+skelaton.width)/2)
	if(Collision_BOBS(&skelaton,&door) == 1)
		{
			// player has reached the end of the lvl. 
			currentstage++;
			skelaton.x = 100;
			skelaton.y = 50;
			skelaton.xv=0;
			skelaton.yv=0;
			Level4_Init();
			return(1);
		}

if(platform.x > platform.x-(platform.width-skelaton.width)/2 && platform.x< platform.x+(platform.width+skelaton.width)/2)
	if(Collision_BOBS(&skelaton,&platform) == 1)
		{
			if(platform.y-50>skelaton.y)
			{
				platformCollision = 1;
				skelaton.y = skelaton.y-abs(skelaton.yv);
				skelaton.yv=0;
				skelaton.xv=0;
				airborne=false;
			}
			else
			{
				skelaton.x-=skelaton.xv;
				skelaton.y-=skelaton.yv;
				skelaton.xv=0;
				skelaton.yv=0;
				platformCollision=1;
			}
		}

bobptr=platform;
bobptr.x=20;
bobptr.y=100;
Draw_BOB(&bobptr,lpddsback);

if(bobptr.x > bobptr.x-(bobptr.width-skelaton.width)/2 && bobptr.x< bobptr.x+(bobptr.width+skelaton.width)/2)
	if(Collision_BOBS(&skelaton,&bobptr) == 1)
		{
			if(bobptr.y-50>skelaton.y)
			{
				skelaton.y = skelaton.y-abs(skelaton.yv);
				skelaton.yv=0;
				skelaton.xv=0;
				airborne=false;
			}
			else
			{
				skelaton.x-=skelaton.xv;
				skelaton.y-=skelaton.yv;
				skelaton.xv=0;
				skelaton.yv=0;
			}
	}

for(int i=0; i<trapnum; i++)
{
	if(triggered[i].shown
		&& traps[i].x > traps[i].x-(traps[i].width-skelaton.width)/2 
		&& traps[i].x< traps[i].x+(traps[i].width+skelaton.width)/2)
		if(Collision_BOBS(&skelaton,&traps[i]) == 1)
			{
				if(traps[i].y-50>skelaton.y)
				{
					skelaton.y = skelaton.y-abs(skelaton.yv);
					skelaton.yv=0;
					skelaton.xv=0;
					airborne=false;
					if(!triggered[i].timing)
					{
						triggered[i].timing=true;
						triggered[i].timer=GetTickCount();
					}
				}
				else
				{
					skelaton.x-=skelaton.xv;
					skelaton.y-=skelaton.yv;
					skelaton.xv*=0.3;
					skelaton.yv=0;
				}
			}
}

if(!platformFlip[0])
{
		if(platform.x > 1000)
			platformFlip[0] = true;

	   // move platform
	   platform.x+=2;
	  // dx=2; dy=0;
	   if(platformCollision)
		   skelaton.x+=2;
}
else
{
		if(platform.x < 700)
			platformFlip[0] = false;

		// move platform
		platform.x+=-2;
		//dx=-2; dy=0;
		if(platformCollision)
			skelaton.x-=2;
}
//Used to tell if the arrow keys were released
if((leftdown && KEY_UP(VK_LEFT)) || (rightdown && KEY_UP(VK_RIGHT)))
	released=true;

if(KEY_DOWN(VK_LSHIFT) && KEY_DOWN(0x04A))
	{skelaton.x=mouse_x; skelaton.y=mouse_y;}

//Move mouse back onto screen
if (mouse_x >= screen_width)
   mouse_x = screen_width-1;
else
if (mouse_x < 0)
   mouse_x = 0;

// now the y boundaries
if (mouse_y >= screen_height)
   mouse_y= screen_height-1;
else
if (mouse_y < 0)
   mouse_y = 0;


//Set cursor object to mouse position
pointer.x = mouse_x - 16;
pointer.y = mouse_y - 16;

//ENDSK

int          index;             // looping var
int          dx,dy;             // general deltas used in collision detection
lpdimouse2->GetDeviceState(sizeof(DIMOUSESTATE), (LPVOID)&mouse_state2);


static int   player_moving = 0; // tracks player motion
static PALETTEENTRY glow = {0,0,0,PC_NOCOLLAPSE};  // used to animation green border

// check of user is trying to exit
if (KEY_DOWN(VK_ESCAPE))
    PostMessage(main_window_handle, WM_DESTROY,0,0);

// start the timing clock
Start_Clock();

// clear the drawing surface
DDraw_Fill_Surface(lpddsback, 0);

// lock the back buffer
DDraw_Lock_Back_Surface();

// draw the background reactor image
Draw_Bitmap(&landscape[3], back_buffer, back_lpitch, 0);

// unlock the back buffer
DDraw_Unlock_Back_Surface();

// reset motion flag
player_moving = 0;



//Scott Keling
//If mouse button was released
if(mousedown && !mouse_state2.rgbButtons[0])
{
	//If on ground, jump
	if(!airborne)
	{
		//Used for motion calculation
		float xchange=0;
		float ychange=0;
		float totalchange=0;
		airborne=true;
		//Get difference in character to mouse position
		xchange=skelaton.x+33-mouse_x;
		ychange=skelaton.y+36-mouse_y-20;
		//Take the total change to get the ratio of rise vs run
		totalchange=abs(xchange)+abs(ychange);
		
		power+=15;
		//Get direction and jump
		int direction;
		if(xchange>0)
			skelaton.xv=-(int)power*abs(xchange/totalchange);
		else
			skelaton.xv=(int)power*abs(xchange/totalchange);
		if(ychange>0)
			skelaton.yv=-(int)power*abs(ychange/totalchange);
		else
			skelaton.yv=(int)power*abs(ychange/totalchange);
	}
	mousedown=false;
	power=0;
}

if(airborne)
{
	int direction;
	if(skelaton.xv>0)
		direction=SKELATON_JUMPING_EAST;
	else
		direction=SKELATON_JUMPING_WEST;
		
	if(skelaton.curr_animation!=SKELATON_JUMPING_EAST 
		&& skelaton.curr_animation!=SKELATON_JUMPING_WEST)
	{Set_Anim_Speed_BOB(&skelaton, 1);
	Set_Animation_BOB(&skelaton,direction);}
}
else if(skelaton.curr_animation!=SKELATON_EAST 
		&& skelaton.curr_animation!=SKELATON_WEST)
{
	Set_Anim_Speed_BOB(&skelaton, 3);
	Set_Animation_BOB(&skelaton,SKELATON_EAST);
}

//If mouse button is down, increment power up to 30
if (mouse_state2.rgbButtons[0])
{
	mousedown=true;
	if(power<25)
		power+=0.50;
}
//ENDSK

// test direction of motion
if (KEY_DOWN(VK_RIGHT) && !airborne) 
   {
	rightdown=true;
   // move skelaton
   skelaton.xv+=4;
   dx=skelaton.xv+4; dy=0;

   // set motion flag
   player_moving = 1;

   // check animation needs to change
   if (skelaton.curr_animation != SKELATON_EAST)
      Set_Animation_BOB(&skelaton,SKELATON_EAST);

   } // end if
else
if (KEY_DOWN(VK_LEFT) && !airborne)  
   {
	leftdown=true;
   // move skelaton
   skelaton.xv-=4;
   dx=skelaton.xv-4; dy=0; 
   
   // set motion flag
   player_moving = 1;

   // check animation needs to change
   if (skelaton.curr_animation != SKELATON_WEST)
      Set_Animation_BOB(&skelaton,SKELATON_WEST);

   } // end if

//Scott Keling
//If left or right key has been released
//Stop character if he is on ground (this keeps him moving in the air)
if(released && !airborne)
{
	skelaton.xv=0;
	leftdown=false;
	rightdown=false;
	released=false;
}


// apply downward gravity to player,
// so player follows terrain
skelaton.y+=skelaton.yv+1;

//apply x velocity
skelaton.x+=skelaton.xv;

// only animate if player is moving
if (player_moving || airborne)
   {
   // animate skelaton
   Animate_BOB(&skelaton);
   } // end if
else
{
	if(skelaton.curr_animation == SKELATON_EAST
	|| skelaton.curr_animation == SKELATON_JUMPING_EAST)
		skelaton.curr_frame=0;
	else
		skelaton.curr_frame=8;
}
// lock surface, so we can scan it
DDraw_Lock_Back_Surface();
   

//Set for if player jumps off platform, 
//next while statement will reset it if player is on ground
airborne=true;
// call the color scanner with FLOOR_COLOR, the color of the glowing floor
// try to center the scan on the feet of the player, make sure feet stay
// in contact with floor
while(Color_Scan(skelaton.x+16, skelaton.y+24,
               skelaton.x+skelaton.width-32, skelaton.y+skelaton.height-12,                                    
               FLOOR_COLOR, FLOOR_COLOR, back_buffer,back_lpitch))
   {
   // push the skelaton upward, to keep it on the floor
	    skelaton.yv=0;
		skelaton.xv=0;
		airborne=false;
		leftdown=false;
		rightdown=false;
		released=false;
		skelaton.y-=skelaton.yv+1;
		
   } // end while
   
// done, so unlock
DDraw_Unlock_Back_Surface();


Draw_BOB(&door,lpddsback);
//draw the spike

//Draw_BOB(&spike,lpddsback);
for(int i=0;i<25;i++)
{
	bobptr=spikeright;
	bobptr.y+=(i*30);
	if(bobptr.y > bobptr.y-(bobptr.height-skelaton.height)/2 && bobptr.y< bobptr.y+(bobptr.height+skelaton.height)/2)
		if(Scaled_Collision_Test(&skelaton,&bobptr, skelaton.width, skelaton.height, 30,30))
			{skelaton.x=50; skelaton.y=40;skelaton.xv=0;skelaton.yv=0;DSound_Play(sound_ids[0],0);deaths++;} 
	Draw_Scaled_BOB(&bobptr,30,30,lpddsback);
	
}

for(int i=0;i<17;i++)
{
	bobptr=spikeright;
	bobptr.x=1090;
	bobptr.y=400+i*30;
	if(bobptr.y > bobptr.y-(bobptr.height-skelaton.height)/2 && bobptr.y< bobptr.y+(bobptr.height+skelaton.height)/2)
		if(Scaled_Collision_Test(&skelaton,&bobptr, skelaton.width, skelaton.height, 30,30))
			{skelaton.x=50; skelaton.y=40;skelaton.xv=0;skelaton.yv=0;DSound_Play(sound_ids[0],0);deaths++;} 
	Draw_Scaled_BOB(&bobptr,30,30,lpddsback);
	
}

for(int i=0;i<19;i++)
{
	bobptr=spikeright;
	bobptr.x=460;
	bobptr.y=0+i*30;
	if(bobptr.y > bobptr.y-(bobptr.height-skelaton.height)/2 && bobptr.y< bobptr.y+(bobptr.height+skelaton.height)/2)
		if(Scaled_Collision_Test(&skelaton,&bobptr, skelaton.width, skelaton.height, 30,30))
			{skelaton.x=50; skelaton.y=40;skelaton.xv=0;skelaton.yv=0;DSound_Play(sound_ids[0],0);deaths++;} 
	Draw_Scaled_BOB(&bobptr,30,30,lpddsback);
	
}

for(int i=0;i<19;i++)
{
	bobptr=spikeleft;
	bobptr.y+=(i*30);
	if(bobptr.y > bobptr.y-(bobptr.height-skelaton.height)/2 && bobptr.y< bobptr.y+(bobptr.height+skelaton.height)/2)
		if(Scaled_Collision_Test(&skelaton,&bobptr, skelaton.width, skelaton.height, 30,30))
			{skelaton.x=40; skelaton.y=40;skelaton.xv=0;skelaton.yv=0;DSound_Play(sound_ids[0],0);deaths++;} 
	Draw_Scaled_BOB(&bobptr,30,30,lpddsback);
	
}

for(int i=0; i<17; i++)
{
	bobptr=spikeleft;
	bobptr.y=400+i*30;
	bobptr.x=880;
	if(bobptr.y > bobptr.y-(bobptr.height-skelaton.height)/2 && bobptr.y< bobptr.y+(bobptr.height+skelaton.height)/2)
		if(Scaled_Collision_Test(&skelaton,&bobptr, skelaton.width, skelaton.height, 30,30))
			{skelaton.x=50; skelaton.y=40;skelaton.xv=0;skelaton.yv=0;DSound_Play(sound_ids[0],0);deaths++;} 
	Draw_Scaled_BOB(&bobptr,30,30,lpddsback);
}

for(int i=0; i<30; i++)
{
	bobptr=spikeleft;
	bobptr.y=0+i*30;
	bobptr.x=1250;
	if(bobptr.y > bobptr.y-(bobptr.height-skelaton.height)/2 && bobptr.y< bobptr.y+(bobptr.height+skelaton.height)/2)
		if(Scaled_Collision_Test(&skelaton,&bobptr, skelaton.width, skelaton.height, 30,30))
			{skelaton.x=50; skelaton.y=40;skelaton.xv=0;skelaton.yv=0;DSound_Play(sound_ids[0],0);deaths++;} 
	Draw_Scaled_BOB(&bobptr,30,30,lpddsback);
}


for(int i=0; i<6; i++)
{
	bobptr=spikeup;
	bobptr.y=370;
	bobptr.x=910+i*30;
	if(bobptr.y > bobptr.y-(bobptr.height-skelaton.height)/2 && bobptr.y< bobptr.y+(bobptr.height+skelaton.height)/2)
		if(Scaled_Collision_Test(&skelaton,&bobptr, skelaton.width, skelaton.height, 30,30))
			{skelaton.x=50; skelaton.y=40;skelaton.xv=0;skelaton.yv=0;DSound_Play(sound_ids[0],0);deaths++;} 
	Draw_Scaled_BOB(&bobptr,30,30,lpddsback);
}

for(int i=0; i<30; i++)
{
	bobptr=spikeup;
	bobptr.x+=(i*30);
	if(bobptr.x > bobptr.x-(bobptr.width-skelaton.width)/2 && bobptr.x< bobptr.x+(bobptr.width+skelaton.width)/2)
		if(Scaled_Collision_Test(&skelaton,&bobptr, skelaton.width, skelaton.height, 30,30))
			{skelaton.x=50; skelaton.y=40;skelaton.xv=0;skelaton.yv=0;DSound_Play(sound_ids[0],0);deaths++;} 
	Draw_Scaled_BOB(&bobptr,30,30,lpddsback);
}

for(int i=0; i<6; i++)
{
	bobptr=spikedown;
	bobptr.x+=(i*30);
	if(bobptr.x > bobptr.x-(bobptr.width-skelaton.width)/2 && bobptr.x< bobptr.x+(bobptr.width+skelaton.width)/2)
		if(Scaled_Collision_Test(&skelaton,&bobptr, skelaton.width, skelaton.height, 30,30))
			{skelaton.x=50; skelaton.y=40;skelaton.xv=0;skelaton.yv=0;DSound_Play(sound_ids[0],0);deaths++;} 
	Draw_Scaled_BOB(&bobptr,30,30,lpddsback);
}
	

for(int i=0;i<trapnum;i++)
{
	if(triggered[i].timing)
	{
		DWORD currtime=GetTickCount();
		if(currtime-triggered[i].timer < 2000)
			Draw_BOB(&traps[i],lpddsback);
		else if(currtime-triggered[i].timer < 7000)
			triggered[i].shown=false;
		else if(currtime-triggered[i].timer > 7000)
		{
			triggered[i].timer=0;
			triggered[i].timing=false;
			triggered[i].shown=true;
		}
	}
	else
		Draw_BOB(&traps[i],lpddsback);
}

//Draw_Scaled_BOB(&spike, 30, 30, lpddsback);

//Draw the wall

for(int i=0; i<4; i++)
{
	bobptr=wall;
	bobptr.y-=(i*180);
	if(bobptr.x > bobptr.x-(bobptr.width-skelaton.width)/2 && bobptr.x< bobptr.x+(bobptr.width+skelaton.width)/2)
		if(Collision_BOBS(&skelaton,&bobptr))
			{
				if(airborne)
				{
				skelaton.x-=skelaton.xv;
				skelaton.y-=skelaton.yv;
				skelaton.xv=0;
				skelaton.yv=0;
				}
				else if(skelaton.curr_animation==SKELATON_EAST)
					skelaton.xv-=5;
				else
					skelaton.xv+=5;
			} 
	Draw_BOB(&bobptr,lpddsback);
}

for(int i=0; i<4; i++)
{
	bobptr=wall;
	bobptr.x=910;
	bobptr.y+=(i*180);
	if(bobptr.x > bobptr.x-(bobptr.width-skelaton.width)/2 
		&& bobptr.x< bobptr.x+(bobptr.width+skelaton.width)/2)
		if(Collision_BOBS(&skelaton,&bobptr))
			{
				if(airborne)
				{
					skelaton.x-=skelaton.xv;
					skelaton.y-=skelaton.yv;
					skelaton.xv=0;
					skelaton.yv=0;
				}
				else if(skelaton.curr_animation==SKELATON_EAST)
					skelaton.xv-=5;
				else
					skelaton.xv+=5;
		}
		Draw_BOB(&bobptr,lpddsback);
}




//draw the platform
Draw_BOB(&platform, lpddsback);
bobptr=platform;
bobptr.x=20;
bobptr.y=100;
Draw_BOB(&bobptr,lpddsback);



// draw the skelaton

//Scott Keling
// draw some text
//sprintf(buffer, "Mouse_x=%d, Mouse_y=%d, skelaton.xv=%f, skelaton.yv=%f", mouse_x, mouse_y, skelaton.xv, skelaton.yv);
sprintf(buffer, "power=%d", (int)(power*4));

//Color power meter
if(power<8)
	Draw_Text_GDI(buffer,8,8,RGB(255,255,255),lpddsback);
else if(power<16)
	Draw_Text_GDI(buffer,8,8,RGB(255,255,0),lpddsback);
else if(power<25)
	Draw_Text_GDI(buffer,8,8,RGB(205,140,0),lpddsback);
else
	Draw_Text_GDI(buffer,8,8,RGB(255,0,0),lpddsback);
//ENDSK
sprintf(buffer, "Deaths=%d", deaths);
Draw_Text_GDI(buffer, 1100, 8, RGB(255,255,255),lpddsback);

// test for page flip right
	if (skelaton.x > SCREEN_WIDTH - (skelaton.width >> 1))
	{
		skelaton.x=-(skelaton.width >> 1);
		skelaton.xv*=-0.3;
		skelaton.yv*=0.3;
	}

else // page flip right?*/
	if (skelaton.x < -(skelaton.width >> 1))
	{
		skelaton.x=-(skelaton.width >> 1);
		skelaton.xv*=-0.3;
		skelaton.yv*=0.3;
	}

Draw_BOB(&skelaton, lpddsback);

//Scott Keling -draw mouse pointer
Draw_BOB(&pointer,lpddsback);

// flip the surfaces
DDraw_Flip();

Destroy_BOB(&bobptr);
// sync to 30 fps
Wait_Clock(30);

firstrun=false;
// return success
return(1);

} // end Game_Main


int Level4_Init()
{
	DMusic_Play(midi_ids[3]);
	return(1);
}

int Level4_Main(void *parms, int num_parms)
{
	if (KEY_DOWN(VK_ESCAPE))
		PostMessage(main_window_handle, WM_DESTROY,0,0);

	// start the timing clock
	Start_Clock();

	DDraw_Fill_Surface(lpddsback, 0);

	// lock the back buffer
	DDraw_Lock_Back_Surface();

	Draw_Bitmap(&landscape[4], back_buffer, back_lpitch, 0);

	DDraw_Unlock_Back_Surface();

	DDraw_Flip();

	// sync to 30 fps
	Wait_Clock(30);
	return(1);
}
int Game_Main(void *parms, int num_parms)
{
// this is the workhorse of your game it will be called
// continuously in real-time this is like main() in C
// all the calls for you game go here!
	switch(currentstage){
		case 0:
			Menu_Main(parms, num_parms);
			break;
		case 1:
			Level1_Main(parms, num_parms);
			break;
		case 2:
			Level2_Main(parms, num_parms);
			break;
		case 3:
			Level3_Main(parms, num_parms);
			break;
		case 4:
			Level4_Main(parms, num_parms);
			break;
		default:
			Menu_Main(parms, num_parms);
	}
	return(1);
}



//////////////////////////////////////////////////////////